@@ -3,7 +3,7 @@
 
 
 package BeamerReveal::Object::BeamerFrame;
-our $VERSION = '20260207.2034'; # VERSION
+our $VERSION = '20260207.2052'; # VERSION
 
 use parent 'BeamerReveal::Object';
 use Carp;
@@ -292,14 +292,14 @@ sub makeSlide {
     if ( exists $animation->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded animation" );
       $aTemplate = $templateStore->fetch( 'html', 'animation-embedded.html' );
-      my ( $mimetype, $file ) =
+      my ( $mimeType, $videoContent ) =
 	$mediaManager->animationFromStore( $generatedContent->{animations}->[$aCounter++],
 				      to_embed => 1 );
       $aStamps =
 	{
 	 %commonStamps,
 	 ANIMATIONID          => 'embedded-id-' . $embeddedID++,
-	 ANIMATIONEMBEDDEDB64 => $imageContent,
+	 ANIMATIONEMBEDDEDB64 => $videoContent,
 	 MIMETYPE             => $mimeType,
 	 FIT                  => $image->{fit}
 	};
@@ -336,14 +336,14 @@ sub makeSlide {
     if ( exists $still->{embed} or $slideEmbed ) {
       $logger->log( 4, "- adding embedded still" );
       $sTemplate = $templateStore->fetch( 'html', 'still-embedded.html' );
-      my ( $mimetype, $file ) =
+      my ( $mimeType, $videoContent ) =
 	$mediaManager->stillFromStore( $generatedContent->{stills}->[$sCounter++],
 				       to_embed => 1 );
       $sStamps =
 	{
 	 %commonStamps,
 	 STILLID          => 'embedded-id-' . $embeddedID++,
-	 STILLEMBEDDEDB64 => $imageContent,
+	 STILLEMBEDDEDB64 => $videoContent,
 	 MIMETYPE         => $mimeType,
 	 FIT              => $image->{fit}
 	};
@@ -560,7 +560,7 @@ BeamerReveal::Object::BeamerFrame - BeamerFrame object
 
 =head1 VERSION
 
-version 20260207.2034
+version 20260207.2052
 
 =head1 SYNOPSIS
 
